/* libmondo-archive.h
 * $Id: libmondo-archive.h 3464 2015-09-10 09:52:41Z bruno $
 */

int archive_this_fileset(char *filelist,
						 char *fname, int setno);
int backup_data();
int call_mindi_to_supply_boot_disks();
bool can_we_fit_these_files_on_media(
									 char *files_to_add, ...);
int do_that_initial_phase();
int do_that_final_phase();
int figure_out_kernel_path_interactively_if_necessary(char *kernel);
bool get_bit_N_of_array(char *array, int N);
int make_those_slices_phase();
int make_those_afios_phase();
int make_slices_and_images(
						   char *biggielist_fname);
int make_iso_fs(char *destfile);
int make_afioballs_and_images();
extern int (*move_files_to_cd) (char *, ...);
int _move_files_to_cd(char *files_to_add, ...);
extern int (*move_files_to_stream) (char *, ...);
int _move_files_to_stream(char *files_to_add,
						  ...);
void pause_and_ask_for_cdr(int, bool *);
void set_bit_N_of_array(char *array, int N, bool true_or_false);
int slice_up_file_etc(char *biggie_filename,
					  char *ntfsprog_fifo,
					  long biggie_file_number, long noof_biggie_files,
					  bool use_ntfsprog);
int verify_data();
void wipe_archives(char *d);
int write_iso_and_go_on(bool last_cd);
int write_final_iso_if_necessary();
int call_growisofs(char *destfile);
int make_afioballs_and_images_SINGLETHREAD();
void setenv_mondo_share(void);
